@@ -18,7 +18,6 @@ import os
 import re
 import shutil
 import sys
-from optparse import OptionParser, OptionGroup
 
 try:
     import configparser
@@ -28,7 +27,6 @@ except ImportError:
 from six.moves import input
 
 from txclib import utils, project
-from txclib.utils import parse_json, compile_json, files_in_project
 from txclib.config import OrderedRawConfigParser
 from txclib.exceptions import UnInitializedError
 from txclib.parsers import delete_parser, help_parser, parse_csv_option, \
@@ -48,30 +46,26 @@ def cmd_init(argv, path_to_tx):
     else:
         path_to_tx = os.getcwd()
 
-    if os.path.isdir(os.path.join(path_to_tx, ".tx")):
+    save = options.save
+    # if we already have a config file and we are not told to override it
+    # in the args we have to ask
+    if os.path.isdir(os.path.join(path_to_tx, ".tx")) and not save:
         logger.info("tx: There is already a tx folder!")
-        reinit = input("Do you want to delete it and "
-                       "reinit the project? [y/N]: ")
-        while (reinit != 'y' and reinit != 'Y' and reinit != 'N'
-               and reinit != 'n' and reinit != ''):
-            reinit = input("Do you want to delete it and "
-                           "reinit the project? [y/N]: ")
-        if not reinit or reinit in ['N', 'n', 'NO', 'no', 'No']:
+        if not utils.confirm(
+            prompt='Do you want to delete it and reinit the project?',
+            default=False
+        ):
             return
         # Clean the old settings
         # FIXME: take a backup
         else:
+            save = True
             rm_dir = os.path.join(path_to_tx, ".tx")
             shutil.rmtree(rm_dir)
 
     logger.info("Creating .tx folder...")
     os.mkdir(os.path.join(path_to_tx, ".tx"))
 
-    # Handle the credentials through transifexrc
-    home = os.path.expanduser("~")
-    txrc = os.path.join(home, ".transifexrc")
-    config = OrderedRawConfigParser()
-
     default_transifex = "https://www.transifex.com"
     transifex_host = options.host or input("Transifex instance [%s]: " %
                                            default_transifex)
@@ -85,6 +79,7 @@ def cmd_init(argv, path_to_tx):
     if not os.path.exists(config_file):
         # The path to the config file (.tx/config)
         logger.info("Creating skeleton...")
+        # Handle the credentials through transifexrc
         config = OrderedRawConfigParser()
         config.add_section('main')
         config.set('main', 'host', transifex_host)
@@ -95,8 +90,9 @@ def cmd_init(argv, path_to_tx):
         fh.close()
 
     prj = project.Project(path_to_tx)
-    prj.getset_host_credentials(transifex_host, user=options.user,
-                                password=options.password)
+    prj.getset_host_credentials(transifex_host, username=options.user,
+                                password=options.password,
+                                token=options.token, save=save)
     prj.save()
     logger.info("Done.")
 
@@ -213,7 +209,7 @@ def _auto_local(path_to_tx, resource, source_language, expression,
     # First, let's construct a dictionary of all matching files.
     # Note: Only the last matching file of a language will be stored.
     translation_files = {}
-    for f_path in files_in_project(curpath):
+    for f_path in utils.files_in_project(curpath):
         match = expr_rec.match(posix_path(f_path))
         if match:
             lang = match.group(1)
@@ -240,7 +236,6 @@ def _auto_local(path_to_tx, resource, source_language, expression,
             'file': os.path.relpath(source_file, curpath)})
 
     prj = project.Project(path_to_tx)
-    root_dir = os.path.abspath(path_to_tx)
 
     if execute:
         try:
@@ -342,6 +337,7 @@ def cmd_push(argv, path_to_tx):
     languages = parse_csv_option(options.languages)
     resources = parse_csv_option(options.resources)
     skip = options.skip_errors
+    xliff = options.xliff
     prj = project.Project(path_to_tx)
     if not (options.push_source or options.push_translations):
         parser.error("You need to specify at least one of the -s|--source, "
@@ -351,7 +347,8 @@ def cmd_push(argv, path_to_tx):
         force=force_creation, resources=resources, languages=languages,
         skip=skip, source=options.push_source,
         translations=options.push_translations,
-        no_interactive=options.no_interactive
+        no_interactive=options.no_interactive,
+        xliff=xliff
     )
     logger.info("Done.")
 
@@ -366,6 +363,8 @@ def cmd_pull(argv, path_to_tx):
     languages = parse_csv_option(options.languages)
     resources = parse_csv_option(options.resources)
     pseudo = options.pseudo
+    # Should we download as xliff?
+    xliff = options.xliff
     skip = options.skip_errors
     minimum_perc = options.minimum_perc or None
 
@@ -381,7 +380,7 @@ def cmd_pull(argv, path_to_tx):
         languages=languages, resources=resources, overwrite=options.overwrite,
         fetchall=options.fetchall, fetchsource=options.fetchsource,
         force=options.force, skip=skip, minimum_perc=minimum_perc,
-        mode=options.mode, pseudo=pseudo
+        mode=options.mode, pseudo=pseudo, xliff=xliff
     )
     logger.info("Done.")
 
