@@ -1,7 +1,12 @@
-import ConfigParser
+try:
+    import configparser
+except ImportError:
+    import ConfigParser as configparser
+
+import six
 
 
-class OrderedRawConfigParser( ConfigParser.RawConfigParser ):
+class OrderedRawConfigParser(configparser.RawConfigParser):
     """
     Overload standard Class ConfigParser.RawConfigParser
     """
@@ -9,17 +14,17 @@ class OrderedRawConfigParser( ConfigParser.RawConfigParser ):
         """Write an .ini-format representation of the configuration state."""
         if self._defaults:
             fp.write("[%s]\n" % DEFAULTSECT)
-            for key in sorted( self._defaults ):
-                fp.write( "%s = %s\n" % (key, str( self._defaults[ key ]
-                    ).replace('\n', '\n\t')) )
+            for key in sorted(self._defaults):
+                fp.write("%s = %s\n" % (key, str(self._defaults[key]).
+                         replace('\n', '\n\t')))
             fp.write("\n")
         for section in self._sections:
             fp.write("[%s]\n" % section)
-            for key in sorted( self._sections[section] ):
+            for key in sorted(self._sections[section]):
                 if key != "__name__":
                     fp.write("%s = %s\n" %
-                        (key, str( self._sections[section][ key ]
-                        ).replace('\n', '\n\t')))
+                             (key, str(self._sections[section][key]).
+                              replace('\n', '\n\t')))
             fp.write("\n")
 
     optionxform = str
@@ -39,7 +44,7 @@ class Flipdict(dict):
     def __init__(self, *args, **kw):
         self._flip = dict.__new__(self.__class__)
         setattr(self._flip, "_flip", self)
-        for key, val in dict(*args, **kw).iteritems():
+        for key, val in six.iteritems(dict(*args, **kw)):
             self[key] = val
 
     @property
@@ -61,7 +66,7 @@ class Flipdict(dict):
 
     def __setitem__(self, key, val):
         k = self._flip.get(val, _NOTFOUND)
-        if not (k is _NOTFOUND or k==key):
+        if not (k is _NOTFOUND or k == key):
             raise KeyError('(key,val) would erase mapping for value %r' % val)
 
         v = self.get(key, _NOTFOUND)
@@ -71,7 +76,7 @@ class Flipdict(dict):
         dict.__setitem__(self,       key, val)
         dict.__setitem__(self._flip, val, key)
 
-    def setdefault(self, key, default = None):
+    def setdefault(self, key, default=None):
         # Copied from python's UserDict.DictMixin code.
         try:
             return self[key]
@@ -79,16 +84,16 @@ class Flipdict(dict):
             self[key] = default
             return default
 
-    def update(self, other = None, **kwargs):
+    def update(self, other=None, **kwargs):
         # Copied from python's UserDict.DictMixin code.
         # Make progressively weaker assumptions about "other"
         if other is None:
             pass
-        elif hasattr(other, 'iteritems'):  # iteritems saves memory and lookups
-            for k, v in other.iteritems():
+        elif hasattr(other, 'items'):
+            for k, v in six.iteritems(other):
                 self[k] = v
         elif hasattr(other, 'keys'):
-            for k in other.keys():
+            for k in list(other.keys()):
                 self[k] = other[k]
         else:
             for k, v in other:
@@ -113,3 +118,9 @@ class Flipdict(dict):
     def clear(self):
         dict.clear(self)
         dict.clear(self._flip)
+
+
+import os
+import ssl
+
+CERT_REQUIRED = getattr(ssl, os.environ.get('TX_CERT_MODE', 'CERT_REQUIRED'))
