@@ -10,6 +10,12 @@ import sys
 import urllib3
 import six
 
+try:
+    import urlparse
+    from urllib import urlencode
+except:  # For Python 3
+    import urllib.parse as urlparse
+    from urllib.parse import urlencode
 try:
     import configparser
 except ImportError:
@@ -24,8 +30,7 @@ from txclib.config import OrderedRawConfigParser, Flipdict, CERT_REQUIRED
 from txclib.log import logger
 from txclib.processors import visit_hostname
 from txclib.paths import posix_path, native_path, posix_sep
-
-
+from txclib.utils import confirm
 
 
 class ProjectNotInit(Exception):
@@ -147,36 +152,90 @@ class Project(object):
             mask = os.umask(0o077)
             open(txrc_file, 'w').close()
             os.umask(mask)
+            if os.path.exists(txrc_file):
+                logger.info('Created %s ' % txrc_file)
+            else:
+                logger.info('Could not create %s ' % txrc_file)
         return txrc_file
 
     def validate_config(self):
         """To ensure the json structure is correctly formed."""
         pass
 
-    def getset_host_credentials(self, host, user=None, password=None):
+    def getset_host_credentials(
+        self,
+        host,
+        username=None,
+        password=None,
+        token=None,
+        save=False
+    ):
         """Read .transifexrc and report user,
-        pass for a specific host else ask the user for input.
+        pass or a token for a specific host else ask the user for input.
         """
-        try:
-            username = self.txrc.get(host, 'username')
-            passwd = self.txrc.get(host, 'password')
-        except (configparser.NoOptionError, configparser.NoSectionError):
-            logger.info("No entry found for host %s. Creating..." % host)
-            username = user or input("Please enter your transifex username: ")
-            while (not username):
-                username = input("Please enter your transifex username: ")
-            passwd = password
-            while (not passwd):
-                passwd = getpass.getpass()
+        # from_config is a flag that tells us if we got the credentials
+        # from the config file
+        from_config = False
+        # first check if a token has been given it should override everything
+        if token:
+            password = token
+            username = 'api'
+        # if neither a token nor a username or a password were given
+        # try to get them from the rc file
+        elif not (username and password):
+            try:
+                username = self.txrc.get(host, 'username')
+                password = self.txrc.get(host, 'password')
+            except (configparser.NoOptionError, configparser.NoSectionError):
+                # if the rc has no credentials, we have to ask the user and
+                # update the rc file
+                save = True
+                # Ask the user if they have an api token
+                if confirm(
+                    prompt="\nDid you know that you can create an api"
+                    "token under your transifex user's settings?\n"
+                    "(Read more at https://docs.transifex.com/api/"
+                    "introduction#authentication)\n"
+                    "So, do you have an api token?",
+                    default=False
 
+                ):
+                    token_msg = "Please enter your api token: "
+                    while not token:
+                        token = input(token_msg)
+                    # Since we got a token, we use api as the username
+                    # and the token as the password
+                    username = 'api'
+                    password = token
+                else:
+                    username_msg = "Please enter your transifex username: "
+                    while not username:
+                        username = input(username_msg)
+                    while (not password):
+                        password = getpass.getpass()
+            else:
+                from_config = True
+
+        # lets see if there is a default username or a password
+        # unless we got the files from the config
+        if not from_config:
+            try:
+                username = self.txrc.get(host, 'username')
+                password = self.txrc.get(host, 'password')
+            except (configparser.NoOptionError, configparser.NoSectionError):
+                # if we do not have defaults, save the give credentials
+                save = True
+
+        if save:
             logger.info("Updating %s file..." % self.txrc_file)
-            self.txrc.add_section(host)
+            if not self.txrc.has_section(host):
+                logger.info("No entry found for host %s. Creating..." % host)
+                self.txrc.add_section(host)
             self.txrc.set(host, 'username', username)
-            self.txrc.set(host, 'password', passwd)
-            self.txrc.set(host, 'token', '')
+            self.txrc.set(host, 'password', password)
             self.txrc.set(host, 'hostname', host)
-
-        return username, passwd
+            self.save()
+        return username, password
 
     def set_remote_resource(self, resource, source_lang, i18n_type, host,
                             file_filter=None):
@@ -261,7 +320,7 @@ class Project(object):
             else:
                 return native_path(source_file)
 
-    def get_resource_files(self, resource):
+    def get_resource_files(self, resource, xliff=False):
         """Get a dict for all files assigned to a resource.
         First we calculate the files matching the file expression and
         then we apply all translation excpetions.
@@ -279,6 +338,9 @@ class Project(object):
                 file_filter = self.config.get(resource, "file_filter")
             except configparser.NoOptionError:
                 file_filter = "$^"
+            if xliff:
+                # update the file-path in case of xliff option
+                file_filter += '.xlf'
             source_lang = self.config.get(resource, "source_lang")
             source_file = self.get_source_file(resource)
             expr_re = utils.regex_from_filefilter(file_filter, self.root)
@@ -380,11 +442,12 @@ class Project(object):
 
     def pull(self, languages=[], resources=[], overwrite=True, fetchall=False,
              fetchsource=False, force=False, skip=False, minimum_perc=0,
-             mode=None, pseudo=False):
+             mode=None, pseudo=False, xliff=False):
         """Pull all translations file from transifex server."""
         self.minimum_perc = minimum_perc
         resource_list = self.get_chosen_resources(resources)
         skip_decode = False
+        params = {}
 
         if mode == 'reviewed':
             url = 'pull_reviewed_file'
@@ -472,8 +535,13 @@ class Project(object):
             if pull_languages:
                 logger.debug("Pulling languages for: %s" % pull_languages)
                 msg = "Pulling translations for resource %s (source: %s)"
+                if xliff:
+                    msg += " [xliff format]"
                 logger.info(msg % (resource, sfile))
 
+            if xliff:
+                params.update({'file': 'xliff'})
+
             for lang in pull_languages:
                 local_lang = lang
                 if lang in list(lang_map.values()):
@@ -496,7 +564,9 @@ class Project(object):
                     'force': force,
                     'mode': mode,
                 }
-                if not self._should_update_translation(**kwargs):
+
+                # xliff files should be always pulled
+                if not xliff and not self._should_update_translation(**kwargs):
                     msg = "Skipping '%s' translation (file: %s)."
                     logger.info(
                         msg % (utils.color_text(remote_lang, "RED"),
@@ -504,6 +574,9 @@ class Project(object):
                     )
                     continue
 
+                if xliff:
+                    local_file += '.xlf'
+
                 if not overwrite:
                     local_file = ("%s.new" % local_file)
                 logger.warning(
@@ -512,7 +585,8 @@ class Project(object):
                 )
                 try:
                     r, charset = self.do_url_request(
-                        url, language=remote_lang, skip_decode=skip_decode
+                        url, language=remote_lang, skip_decode=skip_decode,
+                        params=params
                     )
                 except Exception as e:
                     if isinstance(e, SSLError) or not skip:
@@ -562,20 +636,30 @@ class Project(object):
                     )
 
                     r, charset = self.do_url_request(
-                        url, language=remote_lang, skip_decode=skip_decode
+                        url, language=remote_lang, skip_decode=skip_decode,
+                        params=params
                     )
+                    if xliff:
+                        local_file += '.xlf'
+
                     self._save_file(local_file, charset, r)
 
     def push(self, source=False, translations=False, force=False,
-             resources=[], languages=[], skip=False, no_interactive=False):
+             resources=[], languages=[], skip=False, no_interactive=False,
+             xliff=False):
         """Push all the resources"""
         resource_list = self.get_chosen_resources(resources)
         self.skip = skip
         self.force = force
+
+        params = {}
+        if xliff:
+            params.update({'file_type': 'xliff'})
+
         for resource in resource_list:
             push_languages = []
             project_slug, resource_slug = resource.split('.', 1)
-            files = self.get_resource_files(resource)
+            files = self.get_resource_files(resource, xliff=xliff)
             slang = self.get_resource_option(resource, 'source_lang')
             sfile = self.get_source_file(resource)
             lang_map = self.get_resource_lang_mapping(resource)
@@ -624,6 +708,7 @@ class Project(object):
                         files=[("%s;%s" % (resource_slug, slang),
                                 self.get_full_path(sfile)
                                 )],
+                        params=params,
                     )
                 except Exception as e:
                     if isinstance(e, SSLError) or not skip:
@@ -695,7 +780,8 @@ class Project(object):
                             'push_translation', multipart=True, method='PUT',
                             files=[("%s;%s" % (resource_slug, remote_lang),
                                     self.get_full_path(local_file)
-                                    )], language=remote_lang
+                                    )], language=remote_lang,
+                            params=params,
                         )
                         logger.debug("Translation %s pushed." % remote_lang)
                     except utils.HttpNotFound:
@@ -818,17 +904,17 @@ class Project(object):
                 raise
 
     def do_url_request(self, api_call, multipart=False, data=None,
-                       files=[], method="GET", skip_decode=False, **kwargs):
+                       files=[], method="GET", skip_decode=False,
+                       params={}, **kwargs):
         """Issues a url request."""
         # Read the credentials from the config file (.transifexrc)
         host = self.url_info['host']
+        username, passwd = self.getset_host_credentials(host)
         try:
-            username = self.txrc.get(host, 'username')
-            passwd = self.txrc.get(host, 'password')
             hostname = self.txrc.get(host, 'hostname')
         except configparser.NoSectionError:
             raise Exception(
-                "No user credentials found for host %s. Edit"
+                "No entry found for host %s. Edit"
                 " ~/.transifexrc and add the appropriate"
                 " info in there." % host
             )
@@ -838,6 +924,18 @@ class Project(object):
         kwargs.update(self.url_info)
         url = API_URLS[api_call] % kwargs
 
+        # in case of GET we need to add xliff option as get parameter
+        if params and method == 'GET':
+            # update url params
+            # in case we need to add extra params on a url, we first get the
+            # already existing query, create a dict which will be merged with
+            # the extra params and finally put it back in the url
+            url_parts = list(urlparse.urlparse(url))
+            query = dict(urlparse.parse_qsl(url_parts[4]))
+            query.update(params)
+            url_parts[4] = urlencode(query)
+            url = urlparse.urlunparse(url_parts)
+
         if multipart:
             for info, filename in files:
                 # FIXME: It works because we only pass to files argument
@@ -848,6 +946,9 @@ class Project(object):
                     "language": info.split(';')[1],
                     "uploaded_file": (name, open(filename, 'rb').read())
                 }
+                # in case of PUT we add xliff option as form data
+                if method == 'PUT':
+                    data.update(params)
         return utils.make_request(
             method, hostname, url, username, passwd, data,
             skip_decode=skip_decode
