@@ -1,4 +1,5 @@
 from __future__ import unicode_literals
+import functools
 import os
 import sys
 import re
@@ -6,18 +7,19 @@ import errno
 import urllib3
 import collections
 import six
-import ssl
 
 try:
-    from json import loads as parse_json, dumps as compile_json
+    from json import loads as parse_json
 except ImportError:
-    from simplejson import loads as parse_json, dumps as compile_json
+    from simplejson import loads as parse_json
 
 from email.parser import Parser
 from urllib3.exceptions import SSLError
 from six.moves import input
 from txclib.urls import API_URLS
-from txclib.exceptions import UnknownCommandError, HttpNotFound, HttpNotAuthorized
+from txclib.exceptions import (
+    UnknownCommandError, HttpNotFound, HttpNotAuthorized
+)
 from txclib.paths import posix_path, native_path, posix_sep
 from txclib.web import user_agent_identifier, certs_file
 from txclib.log import logger
@@ -105,7 +107,7 @@ def determine_charset(response):
 
 
 def make_request(method, host, url, username, password, fields=None,
-                 skip_decode=False):
+                 skip_decode=False, get_params={}):
 
     # Initialize http and https pool managers
     num_pools = 1
@@ -153,7 +155,9 @@ def make_request(method, host, url, username, password, fields=None,
     response = None
     try:
         manager = managers[scheme]
-        response = manager.request(
+        # All arguments must be bytes, not unicode
+        encoded_request = encode_args(manager.request)
+        response = encoded_request(
             method,
             host + url,
             headers=dict(headers),
@@ -183,7 +187,6 @@ def make_request(method, host, url, username, password, fields=None,
 def get_details(api_call, username, password, *args, **kwargs):
     """
     Get the tx project info through the API.
-    
     This function can also be used to check the existence of a project.
     """
     url = API_URLS[api_call] % kwargs
@@ -200,7 +203,6 @@ def get_details(api_call, username, password, *args, **kwargs):
 def valid_slug(slug):
     """
     Check if a slug contains only valid characters.
-    
     Valid chars include [-_\w]
     """
     try:
@@ -258,7 +260,6 @@ def mkdir_p(path):
 def confirm(prompt='Continue?', default=True):
     """
     Prompt the user for a Yes/No answer.
-    
     Args:
         prompt: The text displayed to the user ([Y/n] will be appended)
         default: If the default value will be yes or no
@@ -266,10 +267,10 @@ def confirm(prompt='Continue?', default=True):
     valid_yes = ['Y', 'y', 'Yes', 'yes', ]
     valid_no = ['N', 'n', 'No', 'no', ]
     if default:
-        prompt = prompt + '[Y/n]'
+        prompt = prompt + ' [Y/n]: '
         valid_yes.append('')
     else:
-        prompt = prompt + '[y/N]'
+        prompt = prompt + ' [y/N]: '
         valid_no.append('')
 
     ans = input(prompt)
@@ -294,7 +295,6 @@ def color_text(text, color_name, bold=False):
     This command can be used to colorify command line output. If the shell
     doesn't support this or the --disable-colors options has been set, it just
     returns the plain text.
-    
     Usage:
         print "%s" % color_text("This text is red", "RED")
     """
@@ -308,7 +308,6 @@ def color_text(text, color_name, bold=False):
 def files_in_project(curpath):
     """
     Iterate over the files in the project.
-    
     Return each file under ``curpath`` with its absolute name.
     """
     visited = set()
@@ -333,3 +332,47 @@ def files_in_project(curpath):
         )
         for removal in removals:
             dirs.remove(removal)
+
+
+def encode_args(func):
+    # we have to patch func in order to make tests work.
+    # sadly mock does not have the attributes needed for functools
+    # so we need to set the manually
+    if not hasattr(func, '__name__'):
+        functools.update_wrapper(func, str.split, ('__name__', ))
+
+    @functools.wraps(func)
+    def decorated(*args, **kwargs):
+        new_args = _encode_anything(args)
+        new_kwargs = _encode_anything(kwargs, keys_as_unicode=True)
+        return func(*new_args, **new_kwargs)
+    return decorated
+
+
+def _encode_anything(thing, encoding='utf-8', keys_as_unicode=False):
+    # Handle python versions
+    if sys.version_info.major == 3:
+        return thing
+
+    if isinstance(thing, str):
+        return thing
+    elif isinstance(thing, unicode):
+        return thing.encode(encoding)
+    elif isinstance(thing, list):
+        return [_encode_anything(item) for item in thing]
+    elif isinstance(thing, tuple):
+        return tuple(_encode_anything(list(thing)))
+    elif isinstance(thing, dict):
+        # I know this is weird, but when using kwargs in python-3, the keys
+        # should be str, not bytes
+        if keys_as_unicode:
+            return {key: _encode_anything(value)
+                    for key, value in thing.items()}
+        else:
+            return {_encode_anything(key): _encode_anything(value)
+                    for key, value in thing.items()}
+    elif thing is None:
+        return thing
+    else:
+        raise TypeError("Could not encode, unknown type: {}".
+                        format(type(thing)))
